@@ -2,8 +2,7 @@ skip_on_cran()
 
 test_that("cp_classification", {
   vcr::use_cassette("cp_classification", {
-    x <- cp_classification(dataset_key=3, 
-      taxon_id='6565450e-1cf2-4dc2-acbb-db728e42e635')
+    x <- cp_classification(dataset_key=1000, taxon_id=20)
   })
 
   expect_is(x, "data.frame")
